text_data_detector library

Classes

AsciiHostSyntaxValidator
Syntax validator for ASCII domain names.
CalendarCandidate
Internal calendar candidate.
CalendarEventDetector
Finds date and time expressions.
CalendarEventDetectorOptions
Calendar event detector configuration.
CalendarEventValue
Structured value for detected calendar events.
CalendarParsingContext
Shared parsing configuration for calendar patterns.
CalendarPattern
A pattern that finds calendar candidates in text.
DataDetector
Scans text for links, email addresses, phone numbers, and custom data.
DataDetectorMatch
A detected data match with original string range and normalized value.
DataDetectorOptions
Configuration for detector behavior and overlap resolution.
DataDetectorRule
Detects one family of data matches.
DataMatchType
Stable match type identifier.
EmailDetector
Detects email addresses and normalizes IDN domains to Punycode.
EmailDetectorOptions
Email detector configuration.
EnglishMonthNameDatePattern
Finds English month-name dates such as June 11, 2026 and June 11.
EnglishRelativeDatePattern
Finds English relative dates: today, tomorrow, and 3 days ago.
HostNormalizer
Converts user-visible host text to ASCII form for validation.
HostProcessor
HostSyntaxValidator
Validates normalized ASCII host syntax.
HostValidationResult
IdnaHostNormalizer
IDNA-like host normalizer for detector use.
LinkDetector
Detects web URLs and optionally custom scheme:// deep links.
LinkDetectorOptions
Link detector configuration.
NumericDatePattern
Finds numeric dates such as 11.06.2026 and 11/06/2026.
PhoneDetector
Detects phone-number-like text ranges.
PhoneDetectorOptions
Phone detector configuration.
TimePattern
Finds time-only expressions such as 18:30, 6 PM, and 6:30pm.
TimeRangePattern
Finds time ranges such as 18:00-19:00 and 6 PM - 7 PM.

Enums

CalendarCandidateKind
Calendar candidate kind.
NumericDateOrder
Numeric date interpretation for ambiguous dates such as 01/02/2026.
PhoneDetectionMode
Phone parsing strictness.

Extensions

StringDataDetectorExtension on String
Convenience methods for scanning a string with DataDetector.