PhoneDetector class final

Detects phone-number-like text ranges.

Implemented types

Constructors

PhoneDetector({PhoneDetectorOptions options = const PhoneDetectorOptions()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
options PhoneDetectorOptions
Phone-specific detection options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(String text) List<DataDetectorMatch>
Dispatches to strict or loose parsing according to options.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited