CalendarParsingContext class final
Shared parsing configuration for calendar patterns.
Constructors
- CalendarParsingContext({required DateTime referenceDate, required NumericDateOrder numericDateOrder, required int minYear, required int maxYear})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxYear → int
-
Highest accepted year.
final
- minYear → int
-
Lowest accepted year.
final
- numericDateOrder → NumericDateOrder
-
Date order for non-ISO numeric dates.
final
- referenceDate → DateTime
-
Reference date for relative dates and time-only matches.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited