Detects one family of data matches.
Implement this interface to add custom rules. Return ranges in offsets
of the original Dart string; overlapping matches are resolved later by
DataDetector using match weights and range length.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detect(
String text) → List< DataDetectorMatch> -
Returns all matches detected in
text. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited